(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     52450,       1457]
NotebookOptionsPosition[     50716,       1402]
NotebookOutlinePosition[     51398,       1426]
CellTagsIndexPosition[     51355,       1423]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["\n",
  FontSize->24],
 StyleBox["Mathematical model for fitting BrdU data from self-renewing cell \
populations\n\n",
  FontSize->24,
  FontSlant->"Italic"],
 StyleBox["Vitaly V. Ganusov and Rob J. De Boer\n\nMay 2012\n",
  FontSize->16,
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}]
}], "Title",
 CellFrame->3,
 CellChangeTimes->{{3.545606087303336*^9, 3.545606105806817*^9}, {
  3.545606182296514*^9, 3.545606193687*^9}},
 TextAlignment->Center,
 Background->RGBColor[0.667979, 0.4336, 0.671885]],

Cell[TextData[{
 "Here we provide formulas and the code for fitting BrdU labeling data. \
First, we define routine minimum (see below) which allows fitting BrdU data \
(defined in ",
 StyleBox["array", "Code"],
 "), with given residuals (",
 StyleBox["func", "Code"],
 "), fitted parameters (",
 StyleBox["pars", "Code"],
 "), with initial guesses (",
 StyleBox["initpars", "Code"],
 ") with some parameters being positive (",
 StyleBox["conpars", "Code"],
 ")."
}], "Text",
 CellChangeTimes->{{3.545606803977282*^9, 3.545606841397297*^9}, {
  3.545606881584367*^9, 3.545606935349328*^9}, {3.545606981082591*^9, 
  3.54560702967361*^9}},
 FontSize->18],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"minimum", "[", 
    RowBox[{
    "array_", ",", "func_", ",", "pars_", ",", "initpars_", ",", "conpars_", 
     ",", "opt__"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "fpar", ",", "par0", ",", "npar", ",", "constr0", ",", "newpars", ",", 
       "i", ",", "w0", ",", "ww"}], "}"}], ",", 
     RowBox[{
      RowBox[{"w0", "=", 
       RowBox[{"Constrain", "/.", "opt"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ww", "=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], ",", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
             RowBox[{"Exp", "[", 
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], "&"}], ",", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"pars", ",", "conpars"}], "}"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"w0", "=", 
       RowBox[{"w0", "/.", "ww"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"fpar", ",", "par0", ",", "constr0"}], "}"}], "=", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Cases", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{"pars", ",", "initpars", ",", "conpars"}], "}"}], "]"}], 
          ",", 
          RowBox[{"x_", "?", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"!", 
              RowBox[{"NumericQ", "[", 
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "&"}], ")"}]}]}], 
         "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"par0", "=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], ",", 
            RowBox[{"Log", "[", 
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "&"}], ",", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"par0", ",", "constr0"}], "}"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"newpars", "=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "1"}], "&&", 
             RowBox[{"!", 
              RowBox[{"NumericQ", "[", 
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "]"}]}]}], ",", 
            RowBox[{"E", "^", 
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ",", 
            RowBox[{"#", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "&"}], ",", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"pars", ",", "conpars"}], "}"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"npar", "=", 
       RowBox[{"Length", "[", "fpar", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"temp", "=", 
       RowBox[{"FindMinimum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Apply", "[", 
           RowBox[{"Plus", ",", 
            RowBox[{
             RowBox[{"func", "[", 
              RowBox[{"array", ",", "newpars"}], "]"}], "^", "2"}]}], "]"}], 
          "+", "w0"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"fpar", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"par0", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"1.01", "*", 
              RowBox[{"par0", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "npar"}], "}"}]}], "]"}], ",", 
         RowBox[{"AccuracyGoal", "\[Rule]", "eps"}], ",", 
         RowBox[{"PrecisionGoal", "\[Rule]", "eps"}], ",", 
         RowBox[{"MaxIterations", "\[Rule]", 
          RowBox[{"10", "^", "4"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"i", "=", "1"}], ",", 
        RowBox[{"i", "\[LessEqual]", "npar"}], ",", 
        RowBox[{"i", "++"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"constr0", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "\[Equal]", "1"}], ",", 
          RowBox[{
           RowBox[{"temp", "[", 
            RowBox[{"[", 
             RowBox[{"2", ",", "i", ",", "2"}], "]"}], "]"}], "=", 
           RowBox[{"E", "^", 
            RowBox[{"temp", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "i", ",", "2"}], "]"}], "]"}]}]}]}], "]"}]}], 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"ClearAll", "[", 
       RowBox[{
       "npar", ",", "fpar", ",", "par0", ",", "constr0", ",", "newpars", ",", 
        "ww", ",", "w0"}], "]"}], ";", "\[IndentingNewLine]", "temp"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.545606619477112*^9, 3.545606619478963*^9}}],

Cell["\<\

dataset is the input BrdU data in the format {time, fraction of BrdU+ cells}
\
\>", "Text",
 CellChangeTimes->{{3.545606803977282*^9, 3.545606841397297*^9}, {
  3.545606881584367*^9, 3.545606935349328*^9}, {3.545606981082591*^9, 
  3.54560702967361*^9}, {3.545607097688655*^9, 3.545607138562584*^9}, {
  3.545608023273513*^9, 3.545608024317862*^9}},
 FontSize->18],

Cell[BoxData[{
 RowBox[{
  RowBox[{"datasetT", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0.0045000000000000005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "0.3392`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"14", ",", "0.34299999999999997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"21", ",", "0.48350000000000004`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"28", ",", "0.4877`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"35", ",", "0.32689999999999997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"42", ",", "0.19899999999999998`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"49", ",", "0.128`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"70", ",", "0.07`"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tmax", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"datasetT", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.545606226679046*^9, 3.545606227162327*^9}, {
   3.545606457192832*^9, 3.545606457756315*^9}, {3.545606489359978*^9, 
   3.545606509122549*^9}, {3.545606641254409*^9, 3.545606668668782*^9}, {
   3.545607076941812*^9, 3.545607092946068*^9}, 3.545608259777452*^9, 
   3.5614592237168818`*^9}],

Cell["\<\

Main formulas for cells undergone n divisions in the presence of BrdU (X) or \
n divisions during labeling and m divisions during delabeling (Y), and T is \
the total number of cells. Here p is the rate of cell division and d is the \
rate of cell death.
\
\>", "Text",
 CellChangeTimes->{{3.545606803977282*^9, 3.545606841397297*^9}, {
  3.545606881584367*^9, 3.545606935349328*^9}, {3.545606981082591*^9, 
  3.54560702967361*^9}, {3.545607097688655*^9, 3.545607143636591*^9}, {
  3.545607195280661*^9, 3.545607249638645*^9}, {3.545607297588026*^9, 
  3.545607314063821*^9}, {3.545607355005453*^9, 3.545607374126823*^9}, {
  3.545608036114084*^9, 3.545608036697397*^9}},
 FontSize->18],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{
    "X", ",", "Y", ",", "p", ",", "d", ",", "Toff", ",", "Ncr", ",", "T", ",",
      "U", ",", "func", ",", "L", ",", "L0", ",", "MFIneg", ",", "MFIn"}], 
    "]"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"X", "[", 
    RowBox[{"t_", ",", "n_", ",", 
     RowBox[{"{", 
      RowBox[{"p_", ",", "d_", ",", "Toff_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"n", "\[Equal]", "0"}], ",", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"p", "+", "d"}], ")"}]}], "*", "t"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "*", "p", "*", "t"}], ")"}], "^", "n"}], "/", 
       RowBox[{"n", "!"}]}], "*", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"p", "+", "d"}], ")"}]}], "*", "t"}], "]"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Y", "[", 
     RowBox[{"t_", ",", "m_", ",", "n_", ",", 
      RowBox[{"{", 
       RowBox[{"p_", ",", "d_", ",", "Toff_"}], "}"}]}], "]"}], ":=", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"j", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "*", "p", "*", "Toff"}], ")"}], "^", "n"}], "/", 
        RowBox[{"n", "!"}]}], "*", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"p", "+", "d"}], ")"}]}], "*", "Toff"}], "]"}], "*", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"p", "+", "d"}], ")"}]}], "*", 
         RowBox[{"(", 
          RowBox[{"t", "-", "Toff"}], ")"}]}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "*", "p", "*", "Toff"}], ")"}], "^", "n"}], "/", 
        RowBox[{"n", "!"}]}], "*", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"p", "+", "d"}], ")"}]}], "*", "Toff"}], "]"}], "*", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "*", "p", "*", 
           RowBox[{"(", 
            RowBox[{"t", "-", "Toff"}], ")"}]}], ")"}], "^", "m"}], "/", 
        RowBox[{"m", "!"}]}], "*", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"p", "+", "d"}], ")"}]}], "*", 
         RowBox[{"(", 
          RowBox[{"t", "-", "Toff"}], ")"}]}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{"t_", ",", 
      RowBox[{"{", 
       RowBox[{"p_", ",", "d_", ",", "Toff_"}], "}"}]}], "]"}], ":=", 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"p", "-", "d"}], ")"}], "*", "t"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"nmax", "=", "200"}], ";"}]}], "Input",
 CellChangeTimes->{{3.545606226679046*^9, 3.545606227162327*^9}, {
   3.545606457192832*^9, 3.545606457756315*^9}, {3.545606489359978*^9, 
   3.545606509122549*^9}, {3.545606641254409*^9, 3.545606668668782*^9}, {
   3.545607076941812*^9, 3.545607088364536*^9}, {3.545607146233529*^9, 
   3.545607168323631*^9}, {3.545607256605206*^9, 3.545607287270056*^9}, 
   3.545607381415584*^9, {3.545608063198635*^9, 3.545608063555941*^9}, 
   3.561459247854731*^9}],

Cell["\<\

We define the fraction of labeled lymphocytes for a given population L, MFI \
for all cells, or for BrdU+ (MFIpos) and BrdU- (MFIneg) cells.
\
\>", "Text",
 CellChangeTimes->{{3.545606803977282*^9, 3.545606841397297*^9}, {
  3.545606881584367*^9, 3.545606935349328*^9}, {3.545606981082591*^9, 
  3.54560702967361*^9}, {3.545607097688655*^9, 3.545607143636591*^9}, {
  3.545607195280661*^9, 3.545607249638645*^9}, {3.545607297588026*^9, 
  3.545607314063821*^9}, {3.545607355005453*^9, 3.545607436017952*^9}},
 FontSize->18],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"L", "[", 
     RowBox[{"t_", ",", 
      RowBox[{"{", 
       RowBox[{"p_", ",", "d_", ",", "Toff_", ",", "lcr_"}], "}"}]}], "]"}], ":=", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"t", "<", "Toff"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"t", ",", "i", ",", 
           RowBox[{"{", 
            RowBox[{"p", ",", "d", ",", "Toff"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Ceiling", "[", 
            RowBox[{"-", 
             RowBox[{"Log", "[", 
              RowBox[{"2", ",", 
               RowBox[{"1", "-", "lcr"}]}], "]"}]}], "]"}], ",", "nmax"}], 
          "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"Y", "[", 
            RowBox[{"t", ",", "j", ",", "i", ",", 
             RowBox[{"{", 
              RowBox[{"p", ",", "d", ",", "Toff"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "0", ",", 
             RowBox[{"Floor", "[", 
              RowBox[{"Log", "[", 
               RowBox[{"2", ",", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   RowBox[{"2", "^", 
                    RowBox[{"-", "i"}]}]}], ")"}], "/", "lcr"}]}], "]"}], 
              "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Ceiling", "[", 
            RowBox[{"-", 
             RowBox[{"Log", "[", 
              RowBox[{"2", ",", 
               RowBox[{"1", "-", "lcr"}]}], "]"}]}], "]"}], ",", "nmax"}], 
          "}"}]}], "]"}]}], "\[IndentingNewLine]", "]"}], "/", 
     RowBox[{"T", "[", 
      RowBox[{"t", ",", 
       RowBox[{"{", 
        RowBox[{"p", ",", "d", ",", "Toff"}], "}"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"MFI", "[", 
     RowBox[{"t_", ",", 
      RowBox[{"{", 
       RowBox[{"p_", ",", "d_", ",", "Toff_", ",", "lcr_"}], "}"}]}], "]"}], ":=", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"t", "<", "Toff"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", "^", 
             RowBox[{"-", "i"}]}]}], ")"}], "*", 
          RowBox[{"X", "[", 
           RowBox[{"t", ",", "i", ",", 
            RowBox[{"{", 
             RowBox[{"p", ",", "d", ",", "Toff"}], "}"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", "nmax"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"2", "^", 
               RowBox[{"-", "i"}]}]}], ")"}], "*", 
            RowBox[{"2", "^", 
             RowBox[{"-", "j"}]}], "*", 
            RowBox[{"Y", "[", 
             RowBox[{"t", ",", "j", ",", "i", ",", 
              RowBox[{"{", 
               RowBox[{"p", ",", "d", ",", "Toff"}], "}"}]}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "0", ",", "nmax"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", "nmax"}], "}"}]}], "]"}]}], 
      "\[IndentingNewLine]", "]"}], "/", 
     RowBox[{"T", "[", 
      RowBox[{"t", ",", 
       RowBox[{"{", 
        RowBox[{"p", ",", "d", ",", "Toff"}], "}"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"MFIpos", "[", 
     RowBox[{"t_", ",", 
      RowBox[{"{", 
       RowBox[{"p_", ",", "d_", ",", "Toff_", ",", "lcr_"}], "}"}]}], "]"}], ":=", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"t", "<", "Toff"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", "^", 
              RowBox[{"-", "i"}]}]}], ")"}], "*", 
           RowBox[{"X", "[", 
            RowBox[{"t", ",", "i", ",", 
             RowBox[{"{", 
              RowBox[{"p", ",", "d", ",", "Toff"}], "}"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Ceiling", "[", 
             RowBox[{"-", 
              RowBox[{"Log", "[", 
               RowBox[{"2", ",", 
                RowBox[{"1", "-", "lcr"}]}], "]"}]}], "]"}], ",", "nmax"}], 
           "}"}]}], "]"}], "/", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{"X", "[", 
           RowBox[{"t", ",", "i", ",", 
            RowBox[{"{", 
             RowBox[{"p", ",", "d", ",", "Toff"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Ceiling", "[", 
             RowBox[{"-", 
              RowBox[{"Log", "[", 
               RowBox[{"2", ",", 
                RowBox[{"1", "-", "lcr"}]}], "]"}]}], "]"}], ",", "nmax"}], 
           "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"2", "^", 
                RowBox[{"-", "i"}]}]}], ")"}], "*", 
             RowBox[{"2", "^", 
              RowBox[{"-", "j"}]}], "*", 
             RowBox[{"Y", "[", 
              RowBox[{"t", ",", "j", ",", "i", ",", 
               RowBox[{"{", 
                RowBox[{"p", ",", "d", ",", "Toff"}], "}"}]}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "0", ",", 
              RowBox[{"Floor", "[", 
               RowBox[{"Log", "[", 
                RowBox[{"2", ",", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"2", "^", 
                    RowBox[{"-", "i"}]}]}], ")"}], "/", "lcr"}]}], "]"}], 
               "]"}]}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Ceiling", "[", 
             RowBox[{"-", 
              RowBox[{"Log", "[", 
               RowBox[{"2", ",", 
                RowBox[{"1", "-", "lcr"}]}], "]"}]}], "]"}], ",", "nmax"}], 
           "}"}]}], "]"}], "/", "\[IndentingNewLine]", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{"Y", "[", 
             RowBox[{"t", ",", "j", ",", "i", ",", 
              RowBox[{"{", 
               RowBox[{"p", ",", "d", ",", "Toff"}], "}"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "0", ",", 
              RowBox[{"Floor", "[", 
               RowBox[{"Log", "[", 
                RowBox[{"2", ",", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"2", "^", 
                    RowBox[{"-", "i"}]}]}], ")"}], "/", "lcr"}]}], "]"}], 
               "]"}]}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Ceiling", "[", 
             RowBox[{"-", 
              RowBox[{"Log", "[", 
               RowBox[{"2", ",", 
                RowBox[{"1", "-", "lcr"}]}], "]"}]}], "]"}], ",", "nmax"}], 
           "}"}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}], "/", 
     RowBox[{"T", "[", 
      RowBox[{"t", ",", 
       RowBox[{"{", 
        RowBox[{"p", ",", "d", ",", "Toff"}], "}"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MFIneg", "[", 
    RowBox[{"t_", ",", 
     RowBox[{"{", 
      RowBox[{"p_", ",", "d_", ",", "Toff_", ",", "lcr_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"0.01", "+", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"t", "<", "Toff"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", "^", 
              RowBox[{"-", "i"}]}]}], ")"}], "*", 
           RowBox[{"X", "[", 
            RowBox[{"t", ",", "i", ",", 
             RowBox[{"{", 
              RowBox[{"p", ",", "d", ",", "Toff"}], "}"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", 
            RowBox[{"Floor", "[", 
             RowBox[{"-", 
              RowBox[{"Log", "[", 
               RowBox[{"2", ",", 
                RowBox[{"1", "-", "lcr"}]}], "]"}]}], "]"}]}], "}"}]}], "]"}],
         "/", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{"X", "[", 
           RowBox[{"t", ",", "i", ",", 
            RowBox[{"{", 
             RowBox[{"p", ",", "d", ",", "Toff"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", 
            RowBox[{"Floor", "[", 
             RowBox[{"-", 
              RowBox[{"Log", "[", 
               RowBox[{"2", ",", 
                RowBox[{"1", "-", "lcr"}]}], "]"}]}], "]"}]}], "}"}]}], 
         "]"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"2", "^", 
                RowBox[{"-", "i"}]}]}], ")"}], "*", 
             RowBox[{"2", "^", 
              RowBox[{"-", "j"}]}], "*", 
             RowBox[{"Y", "[", 
              RowBox[{"t", ",", "j", ",", "i", ",", 
               RowBox[{"{", 
                RowBox[{"p", ",", "d", ",", "Toff"}], "}"}]}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", 
              RowBox[{"Ceiling", "[", 
               RowBox[{"Log", "[", 
                RowBox[{"2", ",", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "-", 
                    RowBox[{"2", "^", 
                    RowBox[{"-", "i"}]}]}], ")"}], "/", "lcr"}]}], "]"}], 
               "]"}], ",", "nmax"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "nmax"}], "}"}]}], "]"}], "/", 
        "\[IndentingNewLine]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{"Sum", "[", 
             RowBox[{
              RowBox[{"Y", "[", 
               RowBox[{"t", ",", "j", ",", "i", ",", 
                RowBox[{"{", 
                 RowBox[{"p", ",", "d", ",", "Toff"}], "}"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"j", ",", 
                RowBox[{"Ceiling", "[", 
                 RowBox[{"Log", "[", 
                  RowBox[{"2", ",", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"2", "^", 
                    RowBox[{"-", "i"}]}]}], ")"}], "/", "lcr"}]}], "]"}], 
                 "]"}], ",", "nmax"}], "}"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "nmax"}], "}"}]}], "]"}], "+", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{"Y", "[", 
             RowBox[{"t", ",", "j", ",", "0", ",", 
              RowBox[{"{", 
               RowBox[{"p", ",", "d", ",", "Toff"}], "}"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "0", ",", "nmax"}], "}"}]}], "]"}]}], 
         ")"}]}]}], "]"}], "/", 
     RowBox[{"T", "[", 
      RowBox[{"t", ",", 
       RowBox[{"{", 
        RowBox[{"p", ",", "d", ",", "Toff"}], "}"}]}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.545606226679046*^9, 3.545606227162327*^9}, {
   3.545606457192832*^9, 3.545606457756315*^9}, {3.545606489359978*^9, 
   3.545606509122549*^9}, {3.545606641254409*^9, 3.545606668668782*^9}, {
   3.545607076941812*^9, 3.545607088364536*^9}, {3.545607146233529*^9, 
   3.545607168323631*^9}, {3.545607256605206*^9, 3.545607287270056*^9}, 
   3.545607381415584*^9, {3.545607443797842*^9, 3.545607444149309*^9}}],

Cell["\<\

We define the fraction of labeled lymphocytes for a total population given \
that 1st population has a turnover rate p1 and fraction a1 and second \
population has a turnover p2 and fraction 1-a1.
\
\>", "Text",
 CellChangeTimes->{{3.545606803977282*^9, 3.545606841397297*^9}, {
  3.545606881584367*^9, 3.545606935349328*^9}, {3.545606981082591*^9, 
  3.54560702967361*^9}, {3.545607097688655*^9, 3.545607143636591*^9}, {
  3.545607195280661*^9, 3.545607249638645*^9}, {3.545607297588026*^9, 
  3.545607314063821*^9}, {3.545607355005453*^9, 3.545607436017952*^9}, {
  3.545607483838308*^9, 3.545607509787563*^9}},
 FontSize->18],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"L0", "[", 
    RowBox[{"t_", ",", 
     RowBox[{"{", 
      RowBox[{"p_", ",", "Toff_", ",", "lcr_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"L", "[", 
    RowBox[{"t", ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", "p", ",", "Toff", ",", "lcr"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"La", "[", 
     RowBox[{"t_", ",", 
      RowBox[{"{", 
       RowBox[{"p1_", ",", "p2_", ",", "a1_", ",", "Toff_", ",", "lcr_"}], 
       "}"}]}], "]"}], ":=", 
    RowBox[{
     RowBox[{"a1", "*", 
      RowBox[{"L0", "[", 
       RowBox[{"t", ",", 
        RowBox[{"{", 
         RowBox[{"p1", ",", "Toff", ",", "lcr"}], "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "a1"}], ")"}], "*", 
      RowBox[{"L0", "[", 
       RowBox[{"t", ",", 
        RowBox[{"{", 
         RowBox[{"p2", ",", "Toff", ",", "lcr"}], "}"}]}], "]"}]}]}]}], ";"}],
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MFIa", "[", 
    RowBox[{"t_", ",", 
     RowBox[{"{", 
      RowBox[{"p1_", ",", "p2_", ",", "a1_", ",", "Toff_", ",", "lcr_"}], 
      "}"}]}], "]"}], ":=", 
   RowBox[{
    RowBox[{"a1", "*", 
     RowBox[{"MFIpos", "[", 
      RowBox[{"t", ",", 
       RowBox[{"{", 
        RowBox[{"p1", ",", "p1", ",", "Toff", ",", "lcr"}], "}"}]}], "]"}]}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "a1"}], ")"}], "*", 
     RowBox[{"MFIpos", "[", 
      RowBox[{"t", ",", 
       RowBox[{"{", 
        RowBox[{"p2", ",", "p2", ",", "Toff", ",", "lcr"}], "}"}]}], 
      "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"MFIt", "[", 
     RowBox[{"t_", ",", 
      RowBox[{"{", 
       RowBox[{"p1_", ",", "p2_", ",", "a1_", ",", "Toff_", ",", "lcr_"}], 
       "}"}]}], "]"}], ":=", 
    RowBox[{
     RowBox[{"a1", "*", 
      RowBox[{"MFI", "[", 
       RowBox[{"t", ",", 
        RowBox[{"{", 
         RowBox[{"p1", ",", "p1", ",", "Toff", ",", "lcr"}], "}"}]}], "]"}]}],
      "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "a1"}], ")"}], "*", 
      RowBox[{"MFI", "[", 
       RowBox[{"t", ",", 
        RowBox[{"{", 
         RowBox[{"p2", ",", "p2", ",", "Toff", ",", "lcr"}], "}"}]}], 
       "]"}]}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"MFIr", "[", 
     RowBox[{"t_", ",", 
      RowBox[{"{", 
       RowBox[{"p1_", ",", "p2_", ",", "a1_", ",", "Toff_", ",", "lcr_"}], 
       "}"}]}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a1", "*", 
        RowBox[{"MFIpos", "[", 
         RowBox[{"t", ",", 
          RowBox[{"{", 
           RowBox[{"p1", ",", "p1", ",", "Toff", ",", "lcr"}], "}"}]}], 
         "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "a1"}], ")"}], "*", 
        RowBox[{"MFIpos", "[", 
         RowBox[{"t", ",", 
          RowBox[{"{", 
           RowBox[{"p2", ",", "p2", ",", "Toff", ",", "lcr"}], "}"}]}], 
         "]"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a1", "*", 
        RowBox[{"MFIneg", "[", 
         RowBox[{"t", ",", 
          RowBox[{"{", 
           RowBox[{"p1", ",", "p1", ",", "Toff", ",", "lcr"}], "}"}]}], 
         "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "a1"}], ")"}], "*", 
        RowBox[{"MFIneg", "[", 
         RowBox[{"t", ",", 
          RowBox[{"{", 
           RowBox[{"p2", ",", "p2", ",", "Toff", ",", "lcr"}], "}"}]}], 
         "]"}]}]}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"MFIn", "[", 
     RowBox[{"t_", ",", 
      RowBox[{"{", 
       RowBox[{"p1_", ",", "p2_", ",", "a1_", ",", "Toff_", ",", "lcr_"}], 
       "}"}]}], "]"}], ":=", 
    RowBox[{
     RowBox[{"a1", "*", 
      RowBox[{"MFIneg", "[", 
       RowBox[{"t", ",", 
        RowBox[{"{", 
         RowBox[{"p1", ",", "p1", ",", "Toff", ",", "lcr"}], "}"}]}], "]"}]}],
      "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "a1"}], ")"}], "*", 
      RowBox[{"MFIneg", "[", 
       RowBox[{"t", ",", 
        RowBox[{"{", 
         RowBox[{"p2", ",", "p2", ",", "Toff", ",", "lcr"}], "}"}]}], 
       "]"}]}]}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Xa", "[", 
    RowBox[{"t_", ",", "n_", ",", 
     RowBox[{"{", 
      RowBox[{"p1_", ",", "p2_", ",", "a1_", ",", "Toff_", ",", "lcr_"}], 
      "}"}]}], "]"}], ":=", 
   RowBox[{
    RowBox[{"a1", "*", 
     RowBox[{"X", "[", 
      RowBox[{"t", ",", "n", ",", 
       RowBox[{"{", 
        RowBox[{"p1", ",", "p1", ",", "Toff"}], "}"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "a1"}], ")"}], "*", 
     RowBox[{"X", "[", 
      RowBox[{"t", ",", "n", ",", 
       RowBox[{"{", 
        RowBox[{"p2", ",", "p2", ",", "Toff"}], "}"}]}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Ya", "[", 
     RowBox[{"t_", ",", "j_", ",", "i_", ",", 
      RowBox[{"{", 
       RowBox[{"p1_", ",", "p2_", ",", "a1_", ",", "Toff_", ",", "lcr_"}], 
       "}"}]}], "]"}], ":=", 
    RowBox[{
     RowBox[{"a1", "*", 
      RowBox[{"Y", "[", 
       RowBox[{"t", ",", "j", ",", "i", ",", 
        RowBox[{"{", 
         RowBox[{"p1", ",", "p1", ",", "Toff"}], "}"}]}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "a1"}], ")"}], "*", 
      RowBox[{"Y", "[", 
       RowBox[{"t", ",", "j", ",", "i", ",", 
        RowBox[{"{", 
         RowBox[{"p2", ",", "p2", ",", "Toff"}], "}"}]}], "]"}]}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"func", "[", 
    RowBox[{"t_", ",", "pars_"}], "]"}], ":=", 
   RowBox[{"La", "[", 
    RowBox[{"t", ",", "pars"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.545606226679046*^9, 3.545606227162327*^9}, {
  3.545606457192832*^9, 3.545606457756315*^9}, {3.545606489359978*^9, 
  3.545606509122549*^9}, {3.545606641254409*^9, 3.545606668668782*^9}, {
  3.545607076941812*^9, 3.545607088364536*^9}, {3.545607146233529*^9, 
  3.545607168323631*^9}, {3.545607516838318*^9, 3.545607524544229*^9}}],

Cell[TextData[{
 "\nHere we provide initial guesses for all parameters ",
 StyleBox["Par0", "Code"],
 " (p1, p2, a1,T,",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "\[Theta]"], TraditionalForm]]],
 "), define the time of the labeling (here T=21 day), and the threshold for \
labeling ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "\[Theta]"], TraditionalForm]]],
 "(here 0.25)\n"
}], "Text",
 CellChangeTimes->{{3.545606803977282*^9, 3.545606841397297*^9}, {
  3.545606881584367*^9, 3.545606935349328*^9}, {3.545606981082591*^9, 
  3.54560702967361*^9}, {3.545607097688655*^9, 3.545607143636591*^9}, {
  3.545607195280661*^9, 3.545607249638645*^9}, {3.545607297588026*^9, 
  3.545607314063821*^9}, {3.545607355005453*^9, 3.545607436017952*^9}, {
  3.545607533352126*^9, 3.545607549814816*^9}, {3.545607617518633*^9, 
  3.545607638942001*^9}, {3.545607705058644*^9, 3.545607705122317*^9}, {
  3.545607740844061*^9, 3.545607755950783*^9}, {3.54560829786542*^9, 
  3.545608336842455*^9}},
 FontSize->18],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Par0", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.0018695262486366862`", ",", "0.048929974661769536`", ",", 
     "0.46806866604375097`", ",", "21", ",", "0.25`"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"residuals", "[", 
     RowBox[{"array_", ",", "pars_"}], "]"}], ":=", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"func", "[", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", "pars"}], "]"}], "-", 
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "&"}], ",", "array"}], 
     "]"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Apply", "[", 
  RowBox[{"Plus", ",", 
   RowBox[{
    RowBox[{"residuals", "[", 
     RowBox[{"datasetT", ",", "Par0"}], "]"}], "^", "2"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.545606544668658*^9, 3.545606567383849*^9}, {
   3.545606679421711*^9, 3.54560668078393*^9}, 3.545607528058242*^9, 
   3.545608050000287*^9, {3.545608241019264*^9, 3.545608288247224*^9}, 
   3.545608341984221*^9}],

Cell[BoxData["0.01471514297388491`"], "Output",
 CellChangeTimes->{{3.545606231130634*^9, 3.545606244474159*^9}, 
   3.545606464593059*^9, 3.545606570390428*^9, 3.545606681904974*^9, 
   3.545607757842024*^9, {3.54560805060707*^9, 3.545608075648658*^9}, 
   3.545608278946357*^9, 3.54560834285772*^9, {3.561459236692252*^9, 
   3.561459254367324*^9}, 3.5636175185876703`*^9}]
}, Open  ]],

Cell[TextData[{
 "\nHere we provide the basic input for the routine ",
 StyleBox["minimum", "Code"],
 " (defined above). We define all parameters in the model and which \
parameters to be fitted (",
 StyleBox["FitPars", "Code"],
 ": 1 indicate that the parameter is fitted and 0 that it is fixed to a value \
provided by ",
 StyleBox["Par0", "Code"],
 "). ",
 StyleBox["ConPars", "Code"],
 " defines whether the parameter should be constrained to be positive (=1) or \
free to be negative or positive (=0). In our fits we only fit p1, p2, and a1, \
and constrain these parameters to be positive\n"
}], "Text",
 CellChangeTimes->{{3.545606803977282*^9, 3.545606841397297*^9}, {
  3.545606881584367*^9, 3.545606935349328*^9}, {3.545606981082591*^9, 
  3.54560702967361*^9}, {3.545607097688655*^9, 3.545607143636591*^9}, {
  3.545607195280661*^9, 3.545607249638645*^9}, {3.545607297588026*^9, 
  3.545607314063821*^9}, {3.545607355005453*^9, 3.545607436017952*^9}, {
  3.545607533352126*^9, 3.545607549814816*^9}, {3.545607617518633*^9, 
  3.545607638942001*^9}, {3.545607705058644*^9, 3.545607705122317*^9}, {
  3.545607740844061*^9, 3.545607755950783*^9}, {3.54560781234069*^9, 
  3.545607926124943*^9}, {3.545608207462314*^9, 3.545608223913636*^9}},
 FontSize->18],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"ParF", ",", "p", ",", "Toff", ",", "lcr"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AllPars", "=", 
   RowBox[{"{", 
    RowBox[{"p1", ",", "p2", ",", "a1", ",", "Toff", ",", "lcr"}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Npar", "=", 
   RowBox[{"Length", "[", "AllPars", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"FitPars", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", "Npar", "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"FitPars", "=", 
   RowBox[{"ReplacePart", "[", 
    RowBox[{"FitPars", ",", "0", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "4", "}"}], ",", 
       RowBox[{"{", "5", "}"}]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ParF", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"FitPars", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "\[Equal]", "1"}], ",", 
       RowBox[{"AllPars", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", 
       RowBox[{"Par0", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "Npar"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ConPars", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", "Npar", "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"ConPars", "=", 
    RowBox[{"ReplacePart", "[", 
     RowBox[{"ConPars", ",", "0", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "4", "}"}], ",", 
        RowBox[{"{", "5", "}"}]}], "}"}]}], "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Parameters to be fitted are \>\"", ",", 
    RowBox[{"Cases", "[", 
     RowBox[{
      RowBox[{"AllPars", "*", "FitPars"}], ",", 
      RowBox[{"x_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{"NumericQ", "[", "#", "]"}]}], "&"}], ")"}]}]}], "]"}]}], 
   "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Parameters to be constrained (i.e. to be > 0) are \>\"", ",", 
    RowBox[{"Cases", "[", 
     RowBox[{
      RowBox[{"AllPars", "*", "ConPars"}], ",", 
      RowBox[{"x_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{"NumericQ", "[", "#", "]"}]}], "&"}], ")"}]}]}], "]"}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eps", "=", "10"}], ";"}]}], "Input",
 CellChangeTimes->{
  3.545606708319763*^9, {3.545607787558034*^9, 3.545607798769488*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Parameters to be fitted are \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"p1", ",", "p2", ",", "a1"}], "}"}]}],
  SequenceForm[
  "Parameters to be fitted are ", {$CellContext`p1, $CellContext`p2, \
$CellContext`a1}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.545606233002726*^9, 3.545606245461083*^9}, 
   3.545606465682121*^9, 3.545606572457602*^9, {3.545606684806389*^9, 
   3.545606712823818*^9}, {3.545607788567524*^9, 3.545607799265652*^9}, 
   3.545607927483234*^9, 3.545608078333262*^9, 3.545608346275642*^9, {
   3.561459238981204*^9, 3.56145925806024*^9}, 3.563617520873508*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Parameters to be constrained (i.e. to be > 0) are \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"p1", ",", "p2", ",", "a1"}], "}"}]}],
  SequenceForm[
  "Parameters to be constrained (i.e. to be > 0) are ", {$CellContext`p1, \
$CellContext`p2, $CellContext`a1}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.545606233002726*^9, 3.545606245461083*^9}, 
   3.545606465682121*^9, 3.545606572457602*^9, {3.545606684806389*^9, 
   3.545606712823818*^9}, {3.545607788567524*^9, 3.545607799265652*^9}, 
   3.545607927483234*^9, 3.545608078333262*^9, 3.545608346275642*^9, {
   3.561459238981204*^9, 3.56145925806024*^9}, 3.563617520979134*^9}]
}, Open  ]],

Cell[TextData[{
 "\nFitting the data using routine ",
 StyleBox["minimum", "Code"],
 ". If needed, a constrain can be added via option ",
 StyleBox["Constrain", "Code"],
 " (currently set to 0). This is sometimes important as the fraction of cells \
in the first population cannot exceed 1. The fit provides the residual sum of \
squares and best fit parameters using ",
 StyleBox["FindMinimum", "Code"],
 ".\n"
}], "Text",
 CellChangeTimes->{{3.545606803977282*^9, 3.545606841397297*^9}, {
  3.545606881584367*^9, 3.545606935349328*^9}, {3.545606981082591*^9, 
  3.54560702967361*^9}, {3.545607097688655*^9, 3.545607143636591*^9}, {
  3.545607195280661*^9, 3.545607249638645*^9}, {3.545607297588026*^9, 
  3.545607314063821*^9}, {3.545607355005453*^9, 3.545607436017952*^9}, {
  3.545607533352126*^9, 3.545607549814816*^9}, {3.545607617518633*^9, 
  3.545607638942001*^9}, {3.545607705058644*^9, 3.545607705122317*^9}, {
  3.545607740844061*^9, 3.545607755950783*^9}, {3.54560781234069*^9, 
  3.545607992499927*^9}, {3.545608138514015*^9, 3.545608155806157*^9}, {
  3.545608353922581*^9, 3.545608393499249*^9}},
 FontSize->18],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"sol", "=", 
  RowBox[{"minimum", "[", 
   RowBox[{
   "datasetT", ",", "residuals", ",", "ParF", ",", "Par0", ",", "ConPars", 
    ",", 
    RowBox[{"Constrain", "\[Rule]", 
     RowBox[{"0", "*", 
      RowBox[{"10", "^", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"10", "^", "5"}]}], "*", 
         RowBox[{"(", 
          RowBox[{"1", "-", "a1"}], ")"}]}], ")"}]}]}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"VectorQ", "[", 
     RowBox[{
      RowBox[{"ParF", "/.", 
       RowBox[{"sol", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ",", "NumericQ"}], "]"}], ",", 
    RowBox[{"Par0", "=", 
     RowBox[{"ParF", "/.", 
      RowBox[{"sol", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}]}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{
  3.545606710911698*^9, {3.545608132405491*^9, 3.545608132679204*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.01471514297388041`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p1", "\[Rule]", "0.001869527379347391`"}], ",", 
     RowBox[{"p2", "\[Rule]", "0.048929973286070454`"}], ",", 
     RowBox[{"a1", "\[Rule]", "0.4680686505997114`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5614592615389433`*^9, 3.5636175244533978`*^9}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.561459244194188*^9, 3.561459244514452*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.014715142973880772`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p1", "\[Rule]", "0.001869527302137237`"}], ",", 
     RowBox[{"p2", "\[Rule]", "0.048929973373431`"}], ",", 
     RowBox[{"a1", "\[Rule]", "0.4680686527363407`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.545606234665391*^9, 3.545606246866159*^9}, 
   3.545606467626463*^9, {3.545606689466125*^9, 3.545606714276473*^9}, 
   3.545607995887927*^9, 3.545608081377084*^9, 3.545608133487291*^9, 
   3.545608368486642*^9, 3.5614592420306053`*^9}]
}, Open  ]],

Cell[TextData[{
 "\nPlotting the data and results of the fit using ",
 StyleBox["ListPlot", "Code"],
 "\n"
}], "Text",
 CellChangeTimes->{{3.545606803977282*^9, 3.545606841397297*^9}, {
  3.545606881584367*^9, 3.545606935349328*^9}, {3.545606981082591*^9, 
  3.54560702967361*^9}, {3.545607097688655*^9, 3.545607143636591*^9}, {
  3.545607195280661*^9, 3.545607249638645*^9}, {3.545607297588026*^9, 
  3.545607314063821*^9}, {3.545607355005453*^9, 3.545607436017952*^9}, {
  3.545607533352126*^9, 3.545607549814816*^9}, {3.545607617518633*^9, 
  3.545607638942001*^9}, {3.545607705058644*^9, 3.545607705122317*^9}, {
  3.545607740844061*^9, 3.545607755950783*^9}, {3.54560781234069*^9, 
  3.545607926124943*^9}, {3.545608003552182*^9, 3.545608016740263*^9}, {
  3.545608370949104*^9, 3.545608379513691*^9}},
 FontSize->18],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"100", "*", 
            RowBox[{"#", "[", 
             RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], "&"}], ",", 
        "datasetT"}], "]"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Frame", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"TextStyle", "\[Rule]", 
      RowBox[{"FontSize", "\[Rule]", "18"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<days\>\"", ",", "\"\<% BrdU+ cells\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2.5001"}], ",", "100"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotMarkers", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "12"}], "}"}]}]}], "\[IndentingNewLine]", 
    "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", 
          RowBox[{"100", "*", 
           RowBox[{"func", "[", 
            RowBox[{"t", ",", "Par0"}], "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "tmax", ",", "1"}], "}"}]}], "]"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotStyle", "\[Rule]", "Thick"}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.545606254545004*^9, 3.545606445771123*^9}, {
  3.545606722851574*^9, 3.545606777884771*^9}, {3.545608093601218*^9, 
  3.545608100648641*^9}, {3.56361767185627*^9, 3.563617681992378*^9}}],

Cell[BoxData[
 GraphicsBox[{
   GraphicsComplexBox[{{0., 0.45000000000000007`}, {7., 33.92}, {14., 34.3}, {
    21., 48.35}, {28., 48.77}, {35., 32.69}, {42., 19.9}, {49., 12.8}, {70., 
    7.000000000000001}, {0., 0.45000000000000007`}, {7., 33.92}, {14., 
    34.3}, {21., 48.35}, {28., 48.77}, {35., 32.69}, {42., 19.9}, {49., 
    12.8}, {70., 7.000000000000001}}, {
     {Hue[0.67, 0.6, 0.6], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->12], 10], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->12], 11], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->12], 12], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->12], 13], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->12], 14], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->12], 15], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->12], 16], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->12], 17], InsetBox[
       StyleBox["\<\"\[FilledCircle]\"\>",
        StripOnInput->False,
        FontSize->12], 18]}, {}}], {{}, {}, 
    {Hue[0.67, 0.6, 0.6], Thickness[Large], LineBox[CompressedData["
1:eJxt038s1HEcx/GLLBnyhxwh51yuLvJb7gdeh7tD4a6tRquUIV1+pPKz0tkM
KyqJrVnS+olWsxliZNkVmjprVFQyYlNiw+ii0np//+u7fffd4/v8fvb9fj/f
z9cxLm1PggGLxVKs7n+P/99mA120LQefF1uCTuBIz6j+aZUT2Rj12qpUvp0L
2QIbIppW+r55kC1RkZcX6njKh2wNWf2FK4paP7IdbFJK8poqxWQONM5WLR5B
AWQuHtcttE1Hg8xDQi2371aGlOwMH+5yTWtOEHkr9p/4UZV/NJgswMje1rL1
0hCyC4YnMexlLCPvQFisdq6xg7E7ho0z7lsnyske4GTFftL+ZuwJqftnU4NS
BdkLWcvzqnnzULI3JNf5ux4UMvbBZ73+jsUCY180diydTx5ivBOVza/EzmWM
/XBZ5VAn4DIWwqWzIYZXwdxPhL6Lk7rbs8zziGHebrIxWMRYAvsXCiNtJvM+
/uh4m7XGo455/wCYFz9TfH3LzE8gchcTk3oNGANOJwt5AleaTw2wln3acDma
mW8p+kXNowNF9D00UsQ9XVavZARSD0JnuuTM3IQ/9SB8cai6xomXUA+G/KdF
eeN3EfVgOFbfzr5YJKQeggR9w3GRG60PTQhu3LtpaDvhS12Gggwde+9DWk8a
GS690QdM5ntTlyOnq5z/KNGLuhyc0qRp9X5P6gpIApUl3QdofWoUMHi4veRw
ijv1UCQcl/46x3ajHgpzMU/3MtWVehgM63OFNSPbqYfh45DPsckkAfVwWOn4
/OL126iHw+JqtfhoJ5/6Lhgt5kNd4kx91TNpsznJW6jvhr+fzqgglkd9N8x0
N5+cjWf+twjcHWufic3lUo+AwLbbzrPGkXokDoWZzrIGONQjsW++rXeMTWZF
wVPYZr30ejP1KJTODGZOFdtTV6KtS84xibH7ZyjR1ZPdNxhgS9crMS1kicf9
Nv1zpxLj6yK072U2NF6FD2dLp9LjrWm8Cu9s1S055Wwar4LaLFOg67fCH4wJ
Ils=
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  BaseStyle->(FontSize -> 18),
  Frame->{True, True, False, False},
  FrameLabel->{
    FormBox["\"days\"", TraditionalForm], 
    FormBox["\"% BrdU+ cells\"", TraditionalForm]},
  PlotRange->{{0., 70.}, {-2.5001, 100}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Output",
 CellChangeTimes->{
  3.545606255309981*^9, {3.545606285529535*^9, 3.545606360125923*^9}, {
   3.545606437872456*^9, 3.54560646908307*^9}, {3.545606692731965*^9, 
   3.545606779994261*^9}, {3.545608084470255*^9, 3.545608101288103*^9}, 
   3.563617684686562*^9}]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1937, 1398},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{612, 792},
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "vitaly"}, 
  "fit-changing-lcr-BrdU+.ps", CharacterEncoding -> "iso8859-1"]},
ShowSelection->True,
FrontEndVersion->"8.0 for Linux x86 (64-bit) (October 10, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 546, 16, 308, "Title"],
Cell[1106, 38, 652, 18, 61, "Text"],
Cell[1761, 58, 5795, 154, 221, "Input"],
Cell[7559, 214, 375, 9, 83, "Text"],
Cell[7937, 225, 1306, 34, 50, "Input"],
Cell[9246, 261, 697, 14, 107, "Text"],
Cell[9946, 277, 3594, 108, 164, "Input"],
Cell[13543, 387, 534, 11, 83, "Text"],
Cell[14080, 400, 12379, 337, 411, "Input"],
Cell[26462, 739, 639, 13, 83, "Text"],
Cell[27104, 754, 6361, 197, 278, "Input"],
Cell[33468, 953, 1008, 23, 84, "Text"],
Cell[CellGroupData[{
Cell[34501, 980, 1182, 33, 88, "Input"],
Cell[35686, 1015, 375, 5, 30, "Output"]
}, Open  ]],
Cell[36076, 1023, 1264, 24, 133, "Text"],
Cell[CellGroupData[{
Cell[37365, 1051, 2626, 83, 240, "Input"],
Cell[39994, 1136, 660, 13, 23, "Print"],
Cell[40657, 1151, 708, 14, 23, "Print"]
}, Open  ]],
Cell[41380, 1168, 1127, 21, 109, "Text"],
Cell[CellGroupData[{
Cell[42532, 1193, 933, 29, 50, "Input"],
Cell[43468, 1224, 379, 9, 30, "Output"],
Cell[43850, 1235, 92, 1, 30, "Input"],
Cell[43945, 1238, 567, 12, 30, "Output"]
}, Open  ]],
Cell[44527, 1253, 822, 15, 84, "Text"],
Cell[CellGroupData[{
Cell[45374, 1272, 2121, 54, 259, "Input"],
Cell[47498, 1328, 3202, 71, 260, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
